@@ -7,9 +7,7 @@ pub struct SchemaQueryBuilder {
 
 impl SchemaQueryBuilder {
     pub fn new(system: SystemInfo) -> Self {
-        Self {
-            system
-        }
+        Self { system }
     }
 }
 
@@ -25,4 +23,4 @@ pub enum InformationSchema {
     ReferentialConstraints,
     #[iden = "collation_character_set_applicability"]
     CollationCharacterSet,
-}
\ No newline at end of file
+}
