@@ -1,11 +1,11 @@
 pub mod char_set;
 pub mod column;
+pub mod constraints;
 pub mod schema;
 pub mod table;
-pub mod table_constraints;
 
 pub use char_set::*;
 pub use column::*;
+pub use constraints::*;
 pub use schema::*;
 pub use table::*;
-pub use table_constraints::*;
